@@ -13,7 +13,7 @@
 #include <zypp/PathInfo.h>
 #include <zypp/ExternalProgram.h>
 
-#include <zypp/base/Sysconfig.h>
+#include <zypp-core/parser/Sysconfig>
 
 using boost::unit_test::test_suite;
 using boost::unit_test::test_case;
@@ -40,7 +40,7 @@ BOOST_AUTO_TEST_CASE(SysconfigWrite)
   filesystem::copy( file, tmpf.path() );
 
   BOOST_REQUIRE_THROW( zypp::base::sysconfig::writeStringVal( "/tmp/wrzlprmpf", "PROXY_ENABLED", "yes", "# fifi\n fofo\n" ),
-		       zypp::Exception );
+                       zypp::Exception );
   BOOST_CHECK( zypp::base::sysconfig::writeStringVal( tmpf.path(), "PROXY_ENABLED", "yes", "# fifi\n fofo\n" ) );
   BOOST_CHECK( !zypp::base::sysconfig::writeStringVal( tmpf.path(), "NEW1","12" ) );
   BOOST_CHECK( zypp::base::sysconfig::writeStringVal( tmpf.path(), "NEW2","13", "# fifi\n# fofo" ) );
@@ -49,27 +49,27 @@ BOOST_AUTO_TEST_CASE(SysconfigWrite)
   std::ostringstream s;
   ExternalProgram( "diff -u " + file.asString() + " " + tmpf.path().asString() + " | tail -n +3" ) >> s;
   BOOST_CHECK_EQUAL( s.str(),
-		     "@@ -8,7 +8,7 @@\n"
-		     " # This setting allows to turn the proxy on and off while\n"
-		     " # preserving the particular proxy setup.\n"
-		     " #\n"
-		     "-PROXY_ENABLED=\"no\"\n"
-		     "+PROXY_ENABLED=\"yes\"\n"
-		     " \n"
-		     " ## Type:\tstring\n"
-		     " ## Default:\t\"\"\n"
-		     "@@ -49,3 +49,11 @@\n"
-		     " # Example: NO_PROXY=\"www.me.de, do.main, localhost\"\n"
-		     " #\n"
-		     " NO_PROXY=\"localhost, 127.0.0.1\"\n"
-		     "+\n"
-		     "+# fifi\n"
-		     "+# fofo\n"
-		     "+NEW2=\"13\"\n"
-		     "+\n"
-		     "+# fifi\n"
-		     "+# ffofo\n"
-		     "+NEW3=\"13\\\"str\\\"\"\n"
+                     "@@ -8,7 +8,7 @@\n"
+                     " # This setting allows to turn the proxy on and off while\n"
+                     " # preserving the particular proxy setup.\n"
+                     " #\n"
+                     "-PROXY_ENABLED=\"no\"\n"
+                     "+PROXY_ENABLED=\"yes\"\n"
+                     " \n"
+                     " ## Type:\tstring\n"
+                     " ## Default:\t\"\"\n"
+                     "@@ -49,3 +49,11 @@\n"
+                     " # Example: NO_PROXY=\"www.me.de, do.main, localhost\"\n"
+                     " #\n"
+                     " NO_PROXY=\"localhost, 127.0.0.1\"\n"
+                     "+\n"
+                     "+# fifi\n"
+                     "+# fofo\n"
+                     "+NEW2=\"13\"\n"
+                     "+\n"
+                     "+# fifi\n"
+                     "+# ffofo\n"
+                     "+NEW3=\"13\\\"str\\\"\"\n"
   );
 }
 
