@@ -59,11 +59,13 @@ namespace zypp {
     // private data
     class Digest::P
     {
-      P(const P& p);
-      const P& operator=(const P& p);
+      P(const P& p) = delete;
+      const P& operator=(const P& p) = delete;
+      P(P &&) = delete;
+      P &operator=(P &&) = delete;
 
       public:
-        typedef zypp::shared_ptr<EVP_MD_CTX> EvpDataPtr;
+        using EvpDataPtr = zypp::shared_ptr<EVP_MD_CTX>;
         P();
         ~P();
 
@@ -91,7 +93,7 @@ namespace zypp {
     bool Digest::P::openssl_digests_added = false;
 
     Digest::P::P() :
-      md(NULL),
+      md(nullptr),
       finalized(false)
     {
     }
@@ -120,7 +122,7 @@ namespace zypp {
 
         OPENSSL_init_crypto( OPENSSL_INIT_ADD_ALL_DIGESTS, nullptr );
 #else
-# if OPENSSL_API_LEVEL >= 10100
+# if OPENSSL_VERSION_NUMBER >= 0x10100000L
         OPENSSL_init_crypto( OPENSSL_INIT_LOAD_CONFIG, nullptr );
 # else
         OPENSSL_config(NULL);
@@ -179,11 +181,11 @@ namespace zypp {
     {
     }
 
-    Digest::Digest(Digest &&other) : _dp( std::move(other._dp) )
+    Digest::Digest(Digest &&other) noexcept : _dp( std::move(other._dp) )
     {
     }
 
-    Digest &Digest::operator=(Digest &&other)
+    Digest &Digest::operator=(Digest &&other) noexcept
     {
       _dp = std::move( other._dp );
       return *this;
@@ -255,7 +257,7 @@ namespace zypp {
 #ifdef __cpp_lib_string_view
     namespace {
       template <typename BArr>
-      BArr hexStrToBArr ( std::string_view &&str ) {
+      BArr hexStrToBArr ( std::string_view str ) {
         BArr bytes;
         for ( std::string::size_type i = 0; i < str.length(); i+=2 )
         {
@@ -339,7 +341,7 @@ namespace zypp {
 
       while(is.good())
       {
-        size_t readed;
+        size_t readed = 0;
         is.read(buf, bufsize);
         readed = is.gcount();
         if(readed && !update(buf, readed))
