@@ -12,6 +12,7 @@
 #ifndef   ZYPP_URL_H
 #define   ZYPP_URL_H
 
+#include <set>
 #include <zypp-core/url/UrlBase.h>
 #include <zypp-core/url/UrlUtils.h>
 
@@ -88,18 +89,18 @@ namespace zypp
    * \endcode
    *
    */
-  class Url
+  class ZYPP_API Url
   {
   public:
     /**
      * Encoding flags.
      */
-    typedef zypp::url::EEncoding    EEncoding;
+    using EEncoding = zypp::url::EEncoding;
 
     /**
      * View options.
      */
-    typedef zypp::url::ViewOptions  ViewOptions;
+    using ViewOptions = zypp::url::ViewOptions;
 
 
     ~Url();
@@ -128,7 +129,7 @@ namespace zypp
      * \param url The URL implementation reference to make a copy of.
      * \throws url::UrlException if reference is empty.
      */
-    Url(const zypp::url::UrlRef &url);
+    Url(zypp::url::UrlRef url);
 
 
     /**
@@ -147,6 +148,12 @@ namespace zypp
     Url(const std::string &encodedUrl);
 
 
+    /**
+     * @brief Move construct a Url object
+     */
+    Url(Url &&other) = default;
+
+
     // -----------------
     /**
      * \brief Parse a percent-encoded URL string.
@@ -201,6 +208,12 @@ namespace zypp
     operator = (const Url &url);
 
 
+    /**
+     * \brief Moves the data from other into the current object
+     */
+    Url &operator=(Url &&other) = default;
+
+
     // -----------------
     /**
      * \brief Register a scheme-specific implementation.
@@ -792,6 +805,10 @@ namespace zypp
     void
     delQueryParam(const std::string &param);
 
+    /** \brief remove multiple query parameters at once */
+    void
+    delQueryParams(const std::set<std::string> &params);
+
 
     // -----------------
     /**
@@ -834,20 +851,20 @@ namespace zypp
     url::UrlRef m_impl;
   };
 
-  std::ostream & operator<<( std::ostream & str, const Url & url );
+  std::ostream & operator<<( std::ostream & str, const Url & url ) ZYPP_API;
 
   /**
    * needed for std::set
    */
-  bool operator<( const Url &lhs, const Url &rhs );
+  bool operator<( const Url &lhs, const Url &rhs ) ZYPP_API;
 
   /**
    * needed for find
    */
-  bool operator==( const Url &lhs, const Url &rhs );
+  bool operator==( const Url &lhs, const Url &rhs ) ZYPP_API;
 
 
-  bool operator!=( const Url &lhs, const Url &rhs );
+  bool operator!=( const Url &lhs, const Url &rhs ) ZYPP_API;
 
   ////////////////////////////////////////////////////////////////////
 } // namespace zypp
