@@ -17,6 +17,7 @@
 #include <iostream>
 #include <fstream>
 #include <iomanip>
+#include <utility>
 
 #include <zypp-core/fs/PathInfo.h>
 #include <zypp-core/base/LogTools.h>
@@ -137,8 +138,8 @@ namespace zypp
     //	METHOD NAME : PathInfo::PathInfo
     //	METHOD TYPE : Constructor
     //
-    PathInfo::PathInfo( const Pathname & path, Mode initial )
-    : path_t( path )
+    PathInfo::PathInfo( Pathname  path, Mode initial )
+    : path_t(std::move( path ))
     , mode_e( initial )
     , error_i( -1 )
     {
@@ -281,11 +282,15 @@ namespace zypp
     //
     ///////////////////////////////////////////////////////////////////
 
-#define logResult MIL << endl, doLogResult
+#define logResult( ... ) doLogResult( __FUNCTION__, __LINE__, __VA_ARGS__ )
     namespace {
       /**  Helper function to log return values. */
-      inline int doLogResult( const int res, const char * rclass = 0 /*errno*/ )
+      inline int doLogResult( const char *function, const int line, const int res, const char * rclass = 0 /*errno*/ )
       {
+        // calling code has started a logline via: `MIL << "Some text";` but did not flush it via endl yet.
+        // we need to do this here but pass the actual function and line to getStream, because the last call to it before
+        // flushing is setting the logging location ( function/line ).
+        zypp::base::logger::getStream( ZYPP_BASE_LOGGER_LOGGROUP, zypp::base::logger::E_MIL, L_BASEFILE, function, line ) << endl;
         if ( res )
         {
           if ( rclass )
@@ -379,8 +384,8 @@ namespace zypp
     //
     static int recursive_rmdir_1( const Pathname & dir, bool removeDir = true )
     {
-      DIR * dp;
-      struct dirent * d;
+      DIR * dp = nullptr;
+      struct dirent * d = nullptr;
 
       if ( ! (dp = opendir( dir.c_str() )) )
         return logResult( errno );
@@ -581,7 +586,7 @@ namespace zypp
       return ret;
     }
 
-    int dirForEach( const Pathname & dir_r, function<bool(const Pathname &, const char *const)> fnc_r )
+    int dirForEach( const Pathname & dir_r, const function<bool(const Pathname &, const char *const)>& fnc_r )
     {
       if ( ! fnc_r )
               return 0;
@@ -1098,6 +1103,9 @@ namespace zypp
       return logResult( 0 );
     }
 
+    int chmodApplyUmask( const Pathname & path, mode_t mode )
+    { return chmod( path, applyUmaskTo( mode ) ); }
+
     int addmod( const Pathname & path, mode_t mode )
     {
       mode_t omode( PathInfo( path ).st_mode() );
