@@ -500,7 +500,7 @@ namespace zyppng {
           connectAllTransitions<0>( nS, nS._transitions );
         }
 
-        _state = std::forward<NewState>(nS);
+        _state.template emplace<NewState>( std::forward<NewState>(nS) );
 
         // handle final state things
         if constexpr ( NewState::isFinal ) {
@@ -573,10 +573,10 @@ namespace zyppng {
     static constexpr bool isFinal = isFin;
 
     BasicState( StatemachineType &sm ) : _sm( sm ){}
-    virtual ~BasicState() {}
+    ~BasicState() override {}
 
-    BasicState( BasicState && ) = default;
-    BasicState &operator= ( BasicState && ) = default;
+    BasicState( BasicState && ) noexcept = default;
+    BasicState &operator= ( BasicState && ) noexcept = default;
 
     StatemachineType &stateMachine () {
       return _sm;
