@@ -28,7 +28,7 @@ namespace zyppng {
 
     // Since Linux 2.6.27 we can pass additional flags with the type argument to avoid fcntl
     // if creating sockets fails we might need to change that
-    _socket = ::socket( _domain, _type | SOCK_NONBLOCK | SOCK_CLOEXEC, _protocol );
+    _socket = eintrSafeCall( ::socket, _domain, _type | SOCK_NONBLOCK | SOCK_CLOEXEC, _protocol );
     if ( _socket >= 0 )
       return true;
 
@@ -126,6 +126,8 @@ namespace zyppng {
       }
       case Socket::ClosedState: {
         _state.emplace<SocketPrivate::ClosedState>();
+        if ( z_func()->canRead() )
+          z_func()->finishReadChannel( 0 );
         if ( _socket >= 0 && !_borrowedSocket )
           ::close( _socket );
         _socket = -1;
@@ -458,13 +460,13 @@ namespace zyppng {
     return Ptr( new Socket( domain, type, protocol ) );
   }
 
-  bool Socket::bind( std::shared_ptr<SockAddr> addr )
+  bool Socket::bind( const std::shared_ptr<SockAddr> &addr )
   {
     Z_D();
     if ( !addr || !d->initSocket() )
       return false;
 
-    int res = ::bind( d->_socket, addr->nativeSockAddr(), addr->size() );
+    int res = eintrSafeCall( ::bind, d->_socket, addr->nativeSockAddr(), addr->size() );
     if ( res >= 0) return true;
 
     switch ( errno ) {
@@ -510,7 +512,7 @@ namespace zyppng {
     if ( !d->initSocket() )
       return false;
 
-    int res = ::listen( d->_socket, backlog );
+    int res = eintrSafeCall( ::listen, d->_socket, backlog );
     if ( res >= 0 ) {
       d->transition( Socket::ListeningState );
       return true;
@@ -562,7 +564,7 @@ namespace zyppng {
   Socket::Ptr Socket::fromSocket( int fd, Socket::SocketState state )
   {
 
-    int domain;
+    int domain = 0;
     socklen_t optlen = sizeof(domain);
     int res = getsockopt( fd, SOL_SOCKET, SO_DOMAIN, &domain, &optlen );
     if ( res < 0 ) {
@@ -571,7 +573,7 @@ namespace zyppng {
       return nullptr;
     }
 
-    int protocol;
+    int protocol = 0;
     optlen = sizeof(protocol);
     res = getsockopt( fd, SOL_SOCKET, SO_PROTOCOL, &protocol, &optlen );
     if ( res < 0 ) {
@@ -580,7 +582,7 @@ namespace zyppng {
       return nullptr;
     }
 
-    int type;
+    int type = 0;
     optlen = sizeof(type);
     res = getsockopt( fd, SOL_SOCKET, SO_TYPE, &type, &optlen );
     if ( res < 0 ) {
@@ -624,7 +626,7 @@ namespace zyppng {
     if ( !d->initSocket() )
       return false;
 
-    d->_targetAddr = addr;
+    d->_targetAddr = std::move(addr);
     if ( !d->transition( Socket::ConnectingState ) ) {
       abort();
       return false;
