@@ -21,7 +21,6 @@
 #include <zypp-core/zyppng/base/EventDispatcher>
 #include <zypp-media/MediaConfig>
 #include <ostream>
-#include <fstream>
 
 #include <zypp-media/ng/private/providedbg_p.h>
 
@@ -56,7 +55,7 @@ namespace zyppng::worker {
   ProvideWorker::~ProvideWorker()
   { }
 
-  RpcMessageStream::Ptr ProvideWorker::messageStream() const
+  StompFrameStreamRef ProvideWorker::messageStream() const
   {
     return _stream;
   }
@@ -85,12 +84,12 @@ namespace zyppng::worker {
     connect( *_controlIO, &AsyncDataSource::sigReadFdClosed, *this, &ProvideWorker::readFdClosed );
     connect( *_controlIO, &AsyncDataSource::sigWriteFdClosed, *this, &ProvideWorker::writeFdClosed );
 
-    _stream = RpcMessageStream::create( _controlIO );
+    _stream = StompFrameStream::create( _controlIO );
 
-    return executeHandshake () | mbind( [&]() {
+    return executeHandshake () | and_then( [&]() {
       AutoDisconnect disC[] = {
-        connect( *_stream, &RpcMessageStream::sigMessageReceived, *this, &ProvideWorker::messageReceived ),
-        connect( *_stream, &RpcMessageStream::sigInvalidMessageReceived, *this, &ProvideWorker::onInvalidMessageReceived )
+        connect( *_stream, &StompFrameStream::sigMessageReceived, *this, &ProvideWorker::messageReceived ),
+        connect( *_stream, &StompFrameStream::sigInvalidMessageReceived, *this, &ProvideWorker::onInvalidMessageReceived )
       };
       _loop->run();
       if ( _fatalError )
@@ -129,7 +128,7 @@ namespace zyppng::worker {
           , url
           , localFile.empty () ? std::optional<std::string>() : localFile.asString ()
           , stagingFile.empty () ? std::optional<std::string>() : stagingFile.asString ()
-        ).impl() ) ) {
+        ) ) ) {
       ERR << "Failed to send ProvideStart message" << std::endl;
     }
   }
@@ -142,12 +141,12 @@ namespace zyppng::worker {
       for ( const auto &val : i->second )
         msg.addValue( i->first, val );
     }
-    if ( !_stream->sendMessage( msg.impl() ) ) {
+    if ( !_stream->sendMessage( msg ) ) {
       ERR << "Failed to send ProvideSuccess message" << std::endl;
     }
   }
 
-  void ProvideWorker::provideFailed(const uint32_t id, const uint code, const std::string &reason, const bool transient, const HeaderValueMap extra )
+  void ProvideWorker::provideFailed(const uint32_t id, const ProvideMessage::Code code, const std::string &reason, const bool transient, const HeaderValueMap extra )
   {
     MIL_PRV << "Sending provideFailed for request " << id << " err: " << reason << std::endl;
     auto msg = ProvideMessage::createErrorResponse ( id, code, reason, transient );
@@ -155,13 +154,13 @@ namespace zyppng::worker {
       for ( const auto &val : i->second )
         msg.addValue( i->first, val );
     }
-    if ( !_stream->sendMessage( msg.impl() ) ) {
+    if ( !_stream->sendMessage( msg ) ) {
       ERR << "Failed to send ProvideFailed message" << std::endl;
     }
   }
 
 
-  void ProvideWorker::provideFailed  ( const uint32_t id, const uint code, const bool transient, const zypp::Exception &e )
+  void ProvideWorker::provideFailed  ( const uint32_t id, const ProvideMessage::Code code, const bool transient, const zypp::Exception &e )
   {
     zyppng::HeaderValueMap extra;
     if ( !e.historyEmpty() ) {
@@ -175,10 +174,10 @@ namespace zyppng::worker {
   }
 
 
-  void ProvideWorker::attachSuccess(const uint32_t id)
+  void ProvideWorker::attachSuccess(const uint32_t id, const std::optional<std::string> &localMountPoint)
   {
     MIL_PRV << "Sending attachSuccess for request " << id << std::endl;
-    if ( !_stream->sendMessage( ProvideMessage::createAttachFinished ( id ).impl() ) ) {
+    if ( !_stream->sendMessage( ProvideMessage::createAttachFinished ( id, localMountPoint ) ) ) {
       ERR << "Failed to send AttachFinished message" << std::endl;
     } else {
       MIL << "Sent back attach success" << std::endl;
@@ -188,7 +187,7 @@ namespace zyppng::worker {
   void ProvideWorker::detachSuccess(const uint32_t id)
   {
     MIL_PRV << "Sending detachSuccess for request " << id << std::endl;
-    if ( !_stream->sendMessage( ProvideMessage::createDetachFinished ( id ).impl() ) ) {
+    if ( !_stream->sendMessage( ProvideMessage::createDetachFinished ( id ) ) ) {
       ERR << "Failed to send DetachFinished message" << std::endl;
     }
   }
@@ -199,7 +198,7 @@ namespace zyppng::worker {
     zypp::DtorReset delayedReset( _inControllerRequest );
     _inControllerRequest = true;
 
-    if ( !_stream->sendMessage( request.impl() ) )
+    if ( !_stream->sendMessage( request ) )
       return expected<ProvideMessage>::error( ZYPP_EXCPT_PTR(zypp::Exception("Failed to send message")) );
 
     // flush the io device, this will block until all bytes are written
@@ -210,12 +209,12 @@ namespace zyppng::worker {
       const auto &msg = _stream->nextMessageWait() | [&]( auto &&nextMessage ) {
         if ( !nextMessage ) {
           if ( _fatalError )
-            return expected<RpcMessage>::error( _fatalError );
+            return expected<zypp::PluginFrame>::error( _fatalError );
           else
-            return expected<RpcMessage>::error( ZYPP_EXCPT_PTR(zypp::Exception("Failed to wait for response")) );
+            return expected<zypp::PluginFrame>::error( ZYPP_EXCPT_PTR(zypp::Exception("Failed to wait for response")) );
         }
-        return expected<RpcMessage>::success( std::move(*nextMessage) );
-      } | mbind ( [&]( auto && m) {
+        return expected<zypp::PluginFrame>::success( std::move(*nextMessage) );
+      } | and_then ( [&]( auto && m) {
         return parseReceivedMessage(m);
       } );
 
@@ -257,25 +256,24 @@ namespace zyppng::worker {
   expected<AuthInfo> ProvideWorker::requireAuthorization( const uint32_t id, const zypp::Url &url, const std::string &lastTriedUsername, const int64_t lastTimestamp, const std::map<std::string, std::string> &extraFields )
   {
     return sendAndWaitForResponse( ProvideMessage::createAuthDataRequest( id, url, lastTriedUsername, lastTimestamp, extraFields ), { ProvideMessage::Code::AuthInfo, ProvideMessage::Code::NoAuthData } )
-           | mbind( [&]( ProvideMessage &&m ) {
+           | and_then( [&]( ProvideMessage &&m ) {
                if ( m.code() == ProvideMessage::Code::AuthInfo ) {
 
                 AuthInfo inf;
-                m.forEachVal( [&]( const std::string &name, const ProvideMessage::FieldVal &val ) {
-                  if ( name == AuthInfoMsgFields::Username ) {
-                    inf.username = val.asString();
-                  } else if ( name == AuthInfoMsgFields::Password ) {
-                    inf.password = val.asString();
-                  } else if ( name == AuthInfoMsgFields::AuthTimestamp ) {
-                    inf.last_auth_timestamp = val.asInt64();
+                for( const auto &hdr : m.headers () ) {
+                  if ( hdr.first == AuthInfoMsgFields::Username ) {
+                    inf.username = hdr.second.asString();
+                  } else if ( hdr.first == AuthInfoMsgFields::Password ) {
+                    inf.password = hdr.second.asString();
+                  } else if ( hdr.first == AuthInfoMsgFields::AuthTimestamp ) {
+                    inf.last_auth_timestamp = hdr.second.asInt64();
                   } else {
-                    if ( !val.isString() ) {
-                      ERR << "Ignoring invalid extra value, " << name << " is not of type string" << std::endl;
+                    if ( !hdr.second.isString() ) {
+                      ERR << "Ignoring invalid extra value, " << hdr.first << " is not of type string" << std::endl;
                     }
-                    inf.extraKeys[name] = val.asString();
+                    inf.extraKeys[hdr.first] = hdr.second.asString();
                   }
-                  return true;
-                });
+                }
                 return expected<AuthInfo>::success(inf);
 
                }
@@ -296,25 +294,25 @@ namespace zyppng::worker {
       return expected<void>::error( ZYPP_EXCPT_PTR(zypp::Exception("Failed to receive handshake message")) );;
     }
 
-    auto exp = _stream->parseMessage<zypp::proto::Configuration>( *helo );
+    auto exp = _stream->parseMessage<zyppng::worker::Configuration>( *helo );
     if ( !exp ) {
       invalidMessageReceived( exp.error() );
       return expected<void>::error(exp.error());
     }
 
-    return std::move(*exp) | [&]( auto &&conf ) {
+    return std::move(*exp) | [&]( auto conf ) {
 
       _workerConf = std::move(conf);
 
       auto &mediaConf = zypp::MediaConfig::instance();
-      for( const auto &[key,value] : _workerConf.values() ) {
+      for( const auto &[key,value] : _workerConf ) {
         zypp::Url keyUrl( key );
         if ( keyUrl.getScheme() == "zconfig" && keyUrl.getAuthority() == "main" ) {
           mediaConf.setConfigValue( keyUrl.getAuthority(), zypp::Pathname(keyUrl.getPathName()).basename(), value );
         }
       }
 
-      return initialize( _workerConf ) | mbind([&]( WorkerCaps &&caps ){
+      return initialize( _workerConf ) | and_then([&]( WorkerCaps &&caps ){
 
         caps.set_worker_name( _workerName.data() );
 
@@ -410,7 +408,7 @@ namespace zyppng::worker {
         if ( i != _pendingProvides.end() ) {
           switch ( (*i)->_state ) {
             case ProvideWorkerItem::Pending:
-              _stream->sendMessage ( ProvideMessage::createErrorResponse ( provide.requestId (), ProvideMessage::Code::Cancelled, "Cancelled by user." ).impl() );
+              _stream->sendMessage ( ProvideMessage::createErrorResponse ( provide.requestId (), ProvideMessage::Code::Cancelled, "Cancelled by user." ) );
               _pendingProvides.erase(i);
               break;
             case ProvideWorkerItem::Running:
@@ -430,19 +428,18 @@ namespace zyppng::worker {
     ERR << "Unsupported request with code: " << code << " received!" << std::endl;
   }
 
-  void ProvideWorker::pushSingleMessage( const RpcMessage &message )
+  void ProvideWorker::pushSingleMessage( const zypp::PluginFrame &message )
   {
-    const auto &handle = [&]( const RpcMessage &message ){
-      const auto &msgTypeName = message.messagetypename();
-      if ( msgTypeName == rpc::messageTypeName<zypp::proto::ProvideMessage>() ) {
-        return parseReceivedMessage( message )
-               | mbind( [&]( ProvideMessage &&provide ){
-                   _pendingMessages.push_back(provide);
-                   _msgAvail->start(0);
-                   return expected<void>::success();
-                });
-      }
-      return expected<void>::error( ZYPP_EXCPT_PTR( std::invalid_argument(zypp::str::Str()<<"Unknown message received: " << message.messagetypename())) );
+    const auto &handle = [&]( const zypp::PluginFrame &message ){
+      return parseReceivedMessage (message )
+      | and_then( [&]( ProvideMessage &&provide ){
+          _pendingMessages.push_back(provide);
+          _msgAvail->start(0);
+          return expected<void>::success();
+      })
+      | or_else( [&]( std::exception_ptr ) -> expected<void> {
+        return expected<void>::error( ZYPP_EXCPT_PTR( std::invalid_argument(zypp::str::Str()<<"Unknown message received: " << message.command() )) );
+      });
     };
 
     const auto &exp = handle( message );
@@ -459,7 +456,7 @@ namespace zyppng::worker {
     }
   }
 
-  expected<ProvideMessage> ProvideWorker::parseReceivedMessage(const RpcMessage &m)
+  expected<ProvideMessage> ProvideWorker::parseReceivedMessage( const zypp::PluginFrame &m)
   {
     auto exp = ProvideMessage::create(m);
     if ( !exp )
