@@ -26,7 +26,6 @@
 
 #include <zypp/base/String.h>
 #include <zypp/base/Exception.h>
-#include <zypp-core/base/Gettext.h>
 #include <zypp/sat/Solvable.h>
 #include <zypp/ui/Selectable.h>
 
@@ -35,10 +34,10 @@
 
 namespace ztui {
 
-inline const char * asYesNo( bool val_r ) { return val_r ? _("Yes") : _("No"); }
+const char * asYesNo( bool val_r );  ///> _("Yes") or _("No")
 
 /** Custom sort index type for table rows representing solvables (like detailed search results). */
-typedef std::pair<zypp::sat::Solvable, zypp::ui::Selectable::picklist_size_type> SolvableCSI;
+using SolvableCSI = std::pair<zypp::sat::Solvable, zypp::ui::Selectable::picklist_size_type>;
 
 ///////////////////////////////////////////////////////////////////
 // Custom sort index helpers
@@ -217,7 +216,7 @@ public:
   //! output with \a parent table attributes
   std::ostream & dumpTo( std::ostream & stream, const Table & parent ) const;
 
-  typedef std::vector<std::string> container;
+  using container = std::vector<std::string>;
 
   const boost::any &userData() const
   { return _userData; }
@@ -324,7 +323,7 @@ struct TableRow::Less
 {
   using SortParam = std::tuple<unsigned,bool>;  ///< column and sortCI
 
-  Less( const TableHeader & header_r, std::list<unsigned> by_columns_r )
+  Less( const TableHeader & header_r, const std::list<unsigned>& by_columns_r )
   {
     for ( unsigned curr_column : by_columns_r ) {
       _by_columns.push_back( SortParam( curr_column, header_r.hasStyle( curr_column, table::CStyle::SortCi ) ) );
@@ -398,7 +397,7 @@ private:
 class Table
 {
 public:
-  typedef std::list<TableRow> container;
+  using container = std::list<TableRow>;
 
   static TableLineStyle defaultStyle;
 
@@ -431,7 +430,7 @@ public:
   void sort( std::list<unsigned> && byColumns_r )	{ if ( byColumns_r.size() ) _rows.sort( TableRow::Less( header(), std::move(byColumns_r) ) ); }
 
   /** Custom sort */
-  template<class TCompare, std::enable_if_t<!std::is_integral<TCompare>::value, int> = 0>
+  template<class TCompare, std::enable_if_t<!std::is_integral_v<TCompare>, int> = 0>
   void sort( TCompare && less_r )		{ _rows.sort( std::forward<TCompare>(less_r) ); }
 
   void lineStyle( TableLineStyle st );
