@@ -12,6 +12,7 @@
 
 #include <zypp/base/LogTools.h>
 #include <zypp/base/Regex.h>
+#include <utility>
 #include <zypp-core/base/UserRequestException>
 #include <zypp-media/MediaException>
 #include <zypp/ZYppCallbacks.h>
@@ -33,18 +34,18 @@ IMPL_PTR_TYPE(MediaSetAccess);
 
 ///////////////////////////////////////////////////////////////////
 
-  MediaSetAccess::MediaSetAccess(const Url &url,
-                                 const Pathname & prefered_attach_point)
-      : _url(url)
-      , _prefAttachPoint(prefered_attach_point)
+  MediaSetAccess::MediaSetAccess(Url url,
+                                 Pathname  prefered_attach_point)
+      : _url(std::move(url))
+      , _prefAttachPoint(std::move(prefered_attach_point))
   {}
 
-  MediaSetAccess::MediaSetAccess(const std::string & label_r,
-                                 const Url &url,
-                                 const Pathname & prefered_attach_point)
-      : _url(url)
-      , _prefAttachPoint(prefered_attach_point)
-      , _label( label_r )
+  MediaSetAccess::MediaSetAccess(std::string  label_r,
+                                 Url url,
+                                 Pathname  prefered_attach_point)
+      : _url(std::move(url))
+      , _prefAttachPoint(std::move(prefered_attach_point))
+      , _label(std::move( label_r ))
   {}
 
   MediaSetAccess::~MediaSetAccess()
@@ -59,7 +60,7 @@ IMPL_PTR_TYPE(MediaSetAccess);
   }
 
 
-  void MediaSetAccess::setVerifier( unsigned media_nr, media::MediaVerifierRef verifier )
+  void MediaSetAccess::setVerifier( unsigned media_nr, const media::MediaVerifierRef& verifier )
   {
     if (_medias.find(media_nr) != _medias.end())
     {
@@ -86,9 +87,7 @@ IMPL_PTR_TYPE(MediaSetAccess);
   void MediaSetAccess::releaseFile( const Pathname & file, unsigned media_nr)
   {
     media::MediaManager media_mgr;
-    media::MediaAccessId media;
-
-    media = getMediaAccessId( media_nr);
+    media::MediaAccessId media = getMediaAccessId( media_nr);
     DBG << "Going to release file " << file
         << " from media number " << media_nr << endl;
 
@@ -102,8 +101,7 @@ IMPL_PTR_TYPE(MediaSetAccess);
                                 bool dots, unsigned media_nr )
   {
     media::MediaManager media_mgr;
-    media::MediaAccessId media;
-    media = getMediaAccessId(media_nr);
+    media::MediaAccessId media = getMediaAccessId(media_nr);
 
     // try to attach the media
     if ( ! media_mgr.isAttached(media) )
@@ -240,8 +238,7 @@ IMPL_PTR_TYPE(MediaSetAccess);
     media::MediaManager media_mgr;
 
     for ( const auto &resource : files ) {
-      Pathname file(resource.filename());
-      unsigned media_nr(resource.medianr());
+           unsigned media_nr(resource.medianr());
       media::MediaAccessId media = getMediaAccessId( media_nr );
 
       if ( !media_mgr.isOpen( media ) ) {
@@ -256,7 +253,7 @@ IMPL_PTR_TYPE(MediaSetAccess);
     }
   }
 
-  void MediaSetAccess::provide( ProvideOperation op,
+  void MediaSetAccess::provide( const ProvideOperation& op,
                                 const OnMediaLocation &resource,
                                 ProvideFileOptions options )
   {
@@ -266,7 +263,7 @@ IMPL_PTR_TYPE(MediaSetAccess);
     callback::SendReport<media::MediaChangeReport> report;
     media::MediaManager media_mgr;
 
-    media::MediaAccessId media;
+    media::MediaAccessId media = 0;
 
     do
     {
