@@ -22,7 +22,7 @@
 #include <zypp/media/MediaManager.h>
 #include <zypp/Pathname.h>
 #include <zypp/CheckSum.h>
-#include <zypp/OnMediaLocation.h>
+#include <zypp-core/OnMediaLocation>
 #include <zypp/ManagedFile.h>
 
 ///////////////////////////////////////////////////////////////////
@@ -77,7 +77,7 @@ namespace zypp
      *
      * \endcode
      */
-    class MediaSetAccess : public base::ReferenceCounted, private base::NonCopyable
+    class ZYPP_API MediaSetAccess : public base::ReferenceCounted, private base::NonCopyable
     {
       friend std::ostream & operator<<( std::ostream & str, const MediaSetAccess & obj );
 
@@ -89,15 +89,15 @@ namespace zypp
        * \param prefered_attach_point Prefered attach (mount) point. Use, if
        *        you want to mount the media to a specific directory.
        */
-      MediaSetAccess( const Url &url, const Pathname & prefered_attach_point = "" );
+      MediaSetAccess( Url url, Pathname  prefered_attach_point = "" );
       /** \overload Also taking a \ref label. */
-      MediaSetAccess( const std::string & label_r, const Url &url, const Pathname & prefered_attach_point = "" );
-      ~MediaSetAccess();
+      MediaSetAccess( std::string  label_r, Url url, Pathname  prefered_attach_point = "" );
+      ~MediaSetAccess() override;
 
       /**
        * Sets a \ref MediaVerifier verifier for given media number.
        */
-      void setVerifier( unsigned media_nr, media::MediaVerifierRef verifier );
+      void setVerifier( unsigned media_nr, const media::MediaVerifierRef& verifier );
 
       /**
        * The label identifing this media set and to be sent in a media change request.
@@ -121,6 +121,18 @@ namespace zypp
       };
       ZYPP_DECLARE_FLAGS(ProvideFileOptions,ProvideFileOption);
 
+      /**
+         * Tries to fetch the given files and precaches them. Those files
+         * need to be queried using provideFile and can be read from the cache directly.
+         * The implementation is not allowed to block but needs to use seperate means to
+         * download the files concurrently.
+         * A backend can choose to completely ignore this functionaly, the default implementation
+         * does nothing.
+         *
+         * \param files List of files that should be precached
+         */
+      void precacheFiles(const std::vector<OnMediaLocation> &files);
+
       /**
        * Provides a file from a media location.
        *
@@ -148,7 +160,12 @@ namespace zypp
        *
        * \see zypp::media::MediaManager::provideFile()
        */
-      Pathname provideFile( const OnMediaLocation & resource, ProvideFileOptions options = PROVIDE_DEFAULT, const Pathname &deltafile = Pathname() );
+      Pathname provideFile( const OnMediaLocation & resource, ProvideFileOptions options = PROVIDE_DEFAULT );
+
+      /**
+       * \deprecated The deltafile argument is part of the OnMediaLocation now, use the version of \ref provideFile( const OnMediaLocation & resource, ProvideFileOptions options )
+       */
+      ZYPP_DEPRECATED Pathname provideFile( const OnMediaLocation & resource, ProvideFileOptions options, const Pathname &deltafile );
 
       /**
        * Provides \a file from media \a media_nr.
@@ -244,17 +261,17 @@ namespace zypp
       ///////////////////////////////////////////////////////////////////
       struct ReleaseFileGuard
       {
-	NON_COPYABLE( ReleaseFileGuard );
-	NON_MOVABLE( ReleaseFileGuard );
-	ReleaseFileGuard( MediaSetAccess & media_r, const OnMediaLocation & loc_r )
-	: _media( media_r )
-	, _loc( loc_r )
-	{}
-	~ReleaseFileGuard()
-	{ _media.releaseFile( _loc ); }
+        NON_COPYABLE( ReleaseFileGuard );
+        NON_MOVABLE( ReleaseFileGuard );
+        ReleaseFileGuard( MediaSetAccess & media_r, const OnMediaLocation & loc_r )
+        : _media( media_r )
+        , _loc( loc_r )
+        {}
+        ~ReleaseFileGuard()
+        { _media.releaseFile( _loc ); }
       private:
-	MediaSetAccess & _media;
-	const OnMediaLocation & _loc;
+        MediaSetAccess & _media;
+        const OnMediaLocation & _loc;
       };
 
       /**
@@ -339,12 +356,12 @@ namespace zypp
        */
       Pathname provideFileInternal( const OnMediaLocation &resource, ProvideFileOptions options );
 
-      typedef function<void( media::MediaAccessId, const Pathname & )> ProvideOperation;
+      using ProvideOperation = function<void (media::MediaAccessId, const OnMediaLocation &)>;
 
-      void provide( ProvideOperation op, const OnMediaLocation &resource, ProvideFileOptions options, const Pathname &deltafile );
+      void provide( const ProvideOperation& op, const OnMediaLocation &resource, ProvideFileOptions options );
 
       media::MediaAccessId getMediaAccessId (media::MediaNr medianr);
-      virtual std::ostream & dumpOn( std::ostream & str ) const;
+      std::ostream & dumpOn( std::ostream & str ) const override;
 
     private:
       /** Media or media set URL */
@@ -360,8 +377,8 @@ namespace zypp
 
       std::string _label;
 
-      typedef std::map<media::MediaNr, media::MediaAccessId> MediaMap;
-      typedef std::map<media::MediaNr, media::MediaVerifierRef > VerifierMap;
+      using MediaMap = std::map<media::MediaNr, media::MediaAccessId>;
+      using VerifierMap = std::map<media::MediaNr, media::MediaVerifierRef>;
 
       /** Mapping between media number and Media Access ID */
       MediaMap _medias;
