@@ -34,16 +34,16 @@ namespace zypp
    * Patches can be marked for installation but their
    * installation is a no-op.
    */
-  class Patch : public ResObject
+  class ZYPP_API Patch : public ResObject
   {
     public:
-      typedef Patch                    Self;
-      typedef ResTraits<Self>          TraitsType;
-      typedef TraitsType::PtrType      Ptr;
-      typedef TraitsType::constPtrType constPtr;
+      using Self = Patch;
+      using TraitsType = ResTraits<Self>;
+      using Ptr = TraitsType::PtrType;
+      using constPtr = TraitsType::constPtrType;
 
     public:
-      typedef sat::SolvableSet Contents;
+      using Contents = sat::SolvableSet;
 
       enum Category {
         CAT_OTHER	= 1,	//!< unknown value specified
@@ -74,12 +74,12 @@ namespace zypp
        * \ref asSring( const Patch::SeverityFlag & ).
        */
       enum SeverityFlag {
-	SEV_OTHER	= 1,	//!< unknown value specified
-	SEV_NONE	= 1<<1,	//!< no value specified
-	SEV_LOW		= 1<<2,	//!< Low
-	SEV_MODERATE	= 1<<3,	//!< Moderate
-	SEV_IMPORTANT	= 1<<4,	//!< Important
-	SEV_CRITICAL	= 1<<5	//!< Critical
+        SEV_OTHER	= 1,	//!< unknown value specified
+        SEV_NONE	= 1<<1,	//!< no value specified
+        SEV_LOW		= 1<<2,	//!< Low
+        SEV_MODERATE	= 1<<3,	//!< Moderate
+        SEV_IMPORTANT	= 1<<4,	//!< Important
+        SEV_CRITICAL	= 1<<5	//!< Critical
       };
       ZYPP_DECLARE_FLAGS(SeverityFlags, SeverityFlag);
 
@@ -114,9 +114,9 @@ namespace zypp
       template <class TContainer, typename = typename TContainer::value_type>
       bool isCategory( const TContainer & categories_r ) const
       {
-	for ( const std::string & el : categories_r )
-	{ if ( isCategory( el ) ) return true; }
-	return false;
+        for ( const std::string & el : categories_r )
+        { if ( isCategory( el ) ) return true; }
+        return false;
       }
 
       /** Patch category as enum of wellknown categories.
@@ -150,9 +150,9 @@ namespace zypp
       template <class TContainer, typename = typename TContainer::value_type>
       bool isSeverity( const TContainer & severities_r ) const
       {
-	for ( const std::string & el : severities_r )
-	{ if ( isSeverity( el ) ) return true; }
-	return false;
+        for ( const std::string & el : severities_r )
+        { if ( isSeverity( el ) ) return true; }
+        return false;
       }
 
       /** Severity string mapped to an enum.
@@ -231,20 +231,20 @@ namespace zypp
       /** Ctor */
       Patch( const sat::Solvable & solvable_r );
       /** Dtor */
-      virtual ~Patch();
+      ~Patch() override;
   };
   ZYPP_DECLARE_OPERATORS_FOR_FLAGS(Patch::Categories);
   ZYPP_DECLARE_OPERATORS_FOR_FLAGS(Patch::InteractiveFlags);
   ZYPP_DECLARE_OPERATORS_FOR_FLAGS(Patch::SeverityFlags);
 
   /** \relates Patch::Category string representation.*/
-  std::string asString( const Patch::Category & obj );
+  std::string asString( const Patch::Category & obj ) ZYPP_API;
 
   /** \relates Patch::InteractiveFlag string representation.*/
-  std::string asString( const Patch::InteractiveFlag & obj );
+  std::string asString( const Patch::InteractiveFlag & obj ) ZYPP_API;
 
   /** \relates Patch::SeverityFlag string representation.*/
-  std::string asString( const Patch::SeverityFlag & obj );
+  std::string asString( const Patch::SeverityFlag & obj ) ZYPP_API;
 
   /**
    * Query class for Patch issue references
