@@ -36,23 +36,28 @@ namespace zypp
     //	CLASS NAME : Repository
     //
     /** */
-    class Repository : protected sat::detail::PoolMember
+    class ZYPP_API Repository : protected sat::detail::PoolMember
     {
     public:
-        typedef filter_iterator<detail::ByRepository, sat::detail::SolvableIterator> SolvableIterator;
-        typedef sat::detail::size_type size_type;
-        typedef sat::detail::RepoIdType IdType;
+        using SolvableIterator = filter_iterator<detail::ByRepository, sat::detail::SolvableIterator>;
+        using size_type = sat::detail::size_type;
+        using IdType = sat::detail::RepoIdType;
 
-        typedef sat::ArrayAttr<std::string,std::string> Keywords;
+        using Keywords = sat::ArrayAttr<std::string, std::string>;
 
-        typedef std::string ContentRevision;
-        typedef std::string ContentIdentifier;
+        using ContentRevision = std::string;
+        using ContentIdentifier = std::string;
 
     public:
         /** Default ctor creates \ref noRepository.*/
         Repository()
         : _id( sat::detail::noRepoId ) {}
 
+        Repository(const Repository &) = default;
+        Repository(Repository &&) noexcept = default;
+        Repository &operator=(const Repository &) = default;
+        Repository &operator=(Repository &&) noexcept = default;
+
         /** \ref PoolImpl ctor. */
         explicit Repository( IdType id_r )
         : _id( id_r ) {}
@@ -331,10 +336,10 @@ namespace zypp
     ///////////////////////////////////////////////////////////////////
 
     /** \relates Repository Stream output */
-    std::ostream & operator<<( std::ostream & str, const Repository & obj );
+    std::ostream & operator<<( std::ostream & str, const Repository & obj ) ZYPP_API;
 
     /** \relates Repository XML output */
-    std::ostream & dumpAsXmlOn( std::ostream & str, const Repository & obj );
+    std::ostream & dumpAsXmlOn( std::ostream & str, const Repository & obj ) ZYPP_API;
 
     /** \relates Repository */
     inline bool operator==( const Repository & lhs, const Repository & rhs )
@@ -450,7 +455,7 @@ namespace zypp
       //	CLASS NAME : RepositoryIterator
       //
       /** */
-      class RepositoryIterator : public boost::iterator_adaptor<
+      class ZYPP_API RepositoryIterator : public boost::iterator_adaptor<
             RepositoryIterator                            // Derived
                            , sat::detail::CRepo **        // Base
                            , Repository                   // Value
