@@ -13,6 +13,7 @@
 #define ZYPP_RESPOOLPROXY_H
 
 #include <iosfwd>
+#include <utility>
 
 #include <zypp/base/PtrTypes.h>
 
@@ -31,20 +32,20 @@ namespace zypp
   /** ResPool::instance().proxy();
    * \todo integrate it into ResPool
   */
-  class ResPoolProxy
+  class ZYPP_API ResPoolProxy
   {
     friend std::ostream & operator<<( std::ostream & str, const ResPoolProxy & obj );
     friend std::ostream & dumpOn( std::ostream & str, const ResPoolProxy & obj );
-    typedef std::multimap<ResKind,ui::Selectable::Ptr> SelectablePool;
+    using SelectablePool = std::multimap<ResKind, ui::Selectable::Ptr>;
 
   public:
     /** Implementation  */
     struct Impl;
 
-    typedef MapKVIteratorTraits<SelectablePool>::Value_const_iterator const_iterator;
-    typedef SelectablePool::size_type size_type;
+    using const_iterator = MapKVIteratorTraits<SelectablePool>::Value_const_iterator;
+    using size_type = SelectablePool::size_type;
 
-    typedef ResPool::repository_iterator    repository_iterator;
+    using repository_iterator = ResPool::repository_iterator;
 
   public:
 
@@ -69,7 +70,7 @@ namespace zypp
     { return lookup( pool::ByIdent( ident_r ) ); }
 
     ui::Selectable::Ptr lookup( ResKind kind_r, const std::string & name_r ) const
-    { return lookup( pool::ByIdent( kind_r, name_r ) ); }
+    { return lookup( pool::ByIdent( std::move(kind_r), name_r ) ); }
 
     ui::Selectable::Ptr lookup( const sat::Solvable & solv_r ) const
     { return lookup( pool::ByIdent( solv_r ) ); }
