@@ -19,7 +19,7 @@
 namespace zypp
 { /////////////////////////////////////////////////////////////////
 
-  typedef std::string Vendor;
+  using Vendor = std::string;
 
   /////////////////////////////////////////////////////////////////
 } // namespace zypp
