@@ -22,6 +22,7 @@ extern "C"
 #include <iostream>
 #include <fstream>
 #include <optional>
+#include <zypp-core/APIConfig.h>
 #include <zypp/base/LogTools.h>
 #include <zypp/base/IOStream.h>
 #include <zypp-core/base/InputStream>
@@ -311,13 +312,6 @@ namespace zypp
       return ret;
     }
 
-
-    inline Pathname _autodetectSystemRoot()
-    {
-      Target_Ptr target( getZYpp()->getTarget() );
-      return target ? target->root() : Pathname();
-    }
-
     inline Pathname _autodetectZyppConfPath()
     {
       const char *env_confpath = getenv( "ZYPP_CONF" );
@@ -495,7 +489,7 @@ namespace zypp
         , repo_add_probe          	( false )
         , repo_refresh_delay      	( 10 )
         , repoLabelIsAlias              ( false )
-        , download_use_deltarpm   	( true )
+        , download_use_deltarpm   	( LIBZYPP_CONFIG_USE_DELTARPM_BY_DEFAULT )
         , download_use_deltarpm_always  ( false )
         , download_media_prefer_download( true )
         , download_mediaMountdir	( "/var/adm/mount" )
@@ -508,7 +502,7 @@ namespace zypp
         , geoipEnabled ( true )
         , geoipHosts { "download.opensuse.org" }
       {
-        MIL << "libzypp: " LIBZYPP_VERSION_STRING << endl;
+        MIL << "libzypp: " LIBZYPP_VERSION_STRING << " (" << LIBZYPP_CODESTREAM << ")" << endl;
         if ( PathInfo(_parsedZyppConf).isExist() )
         {
           parser::IniDict dict( _parsedZyppConf );
@@ -664,15 +658,18 @@ namespace zypp
                 }
                 else if ( entry == "update.datadir" )
                 {
-                  update_data_path = Pathname(value);
+                  // ignore, this is a constant anyway and should not be user configurabe
+                  // update_data_path = Pathname(value);
                 }
                 else if ( entry == "update.scriptsdir" )
                 {
-                  update_scripts_path = Pathname(value);
+                  // ignore, this is a constant anyway and should not be user configurabe
+                  // update_scripts_path = Pathname(value);
                 }
                 else if ( entry == "update.messagessdir" )
                 {
-                  update_messages_path = Pathname(value);
+                  // ignore, this is a constant anyway and should not be user configurabe
+                  // update_messages_path = Pathname(value);
                 }
                 else if ( entry == "update.messages.notify" )
                 {
@@ -726,8 +723,23 @@ namespace zypp
       Impl &operator=(Impl &&) = delete;
       ~Impl() {}
 
+      /** bsc#1237044: Provide \ref announceSystemRoot to allow commands
+       * using --root without launching a Target. An announced SystemRoot
+       * is used rather than / when no Target is up. This enables sub
+       * components (e.g. VarReplacer) to refer to the right context.
+       *
+       * Setting or re-setting a Target clears any announced SystemRoot.
+       */
+      Pathname _autodetectSystemRoot() const
+      {
+        Target_Ptr target( getZYpp()->getTarget() );
+        return target ? target->root() : _announced_root_path;
+      }
+
       void notifyTargetChanged()
       {
+        _announced_root_path = Pathname();  // first of all reset any previously _announced_root_path
+
         Pathname newRoot { _autodetectSystemRoot() };
         MIL << "notifyTargetChanged (" << newRoot << ")" << endl;
 
@@ -753,6 +765,7 @@ namespace zypp
     public:
     /** Remember any parsed zypp.conf. */
     Pathname _parsedZyppConf;
+    Pathname _announced_root_path;
 
     Arch     cfg_arch;
     Locale   cfg_textLocale;
@@ -773,9 +786,6 @@ namespace zypp
     std::string cfg_kernel_keep_spec;
     Pathname locks_file;
 
-    Pathname update_data_path;
-    Pathname update_scripts_path;
-    Pathname update_messages_path;
     DefaultOption<std::string> updateMessagesNotify;
 
     bool	repo_add_probe;
@@ -951,7 +961,7 @@ namespace zypp
   { return _pimpl->notifyTargetChanged(); }
 
   Pathname ZConfig::systemRoot() const
-  { return _autodetectSystemRoot(); }
+  { return _pimpl->_autodetectSystemRoot(); }
 
   Pathname ZConfig::repoManagerRoot() const
   {
@@ -962,6 +972,9 @@ namespace zypp
   void ZConfig::setRepoManagerRoot(const zypp::filesystem::Pathname &root)
   { _pimpl->cfg_repo_mgr_root_path = root; }
 
+  void ZConfig::announceSystemRoot( const Pathname & root_r )
+  { _pimpl->_announced_root_path = root_r; }
+
   ///////////////////////////////////////////////////////////////////
   //
   // system architecture
@@ -1265,22 +1278,28 @@ namespace zypp
   bool ZConfig::apply_locks_file() const
   { return _pimpl->apply_locks_file; }
 
-  Pathname ZConfig::update_dataPath() const
+  Pathname ZConfig::update_dataPath()
+#if LEGACY(1735)
+  const
+#endif
   {
-    return ( _pimpl->update_data_path.empty()
-        ? Pathname("/var/adm") : _pimpl->update_data_path );
+    return Pathname("/var/adm");
   }
 
-  Pathname ZConfig::update_messagesPath() const
+  Pathname ZConfig::update_messagesPath()
+#if LEGACY(1735)
+  const
+#endif
   {
-    return ( _pimpl->update_messages_path.empty()
-             ? Pathname(update_dataPath()/"update-messages") : _pimpl->update_messages_path );
+    return Pathname(update_dataPath()/"update-messages");
   }
 
-  Pathname ZConfig::update_scriptsPath() const
+  Pathname ZConfig::update_scriptsPath()
+#if LEGACY(1735)
+  const
+#endif
   {
-    return ( _pimpl->update_scripts_path.empty()
-             ? Pathname(update_dataPath()/"update-scripts") : _pimpl->update_scripts_path );
+    return Pathname(update_dataPath()/"update-scripts");
   }
 
   std::string ZConfig::updateMessagesNotify() const
@@ -1333,7 +1352,7 @@ namespace zypp
 
   std::ostream & ZConfig::about( std::ostream & str ) const
   {
-    str << "libzypp: " LIBZYPP_VERSION_STRING << endl;
+    str << "libzypp: " LIBZYPP_VERSION_STRING << " (" << LIBZYPP_CODESTREAM << ")" << endl;
 
     str << "libsolv: " << solv_version;
     if ( ::strcmp( solv_version, LIBSOLV_VERSION_STRING ) )
