@@ -16,7 +16,7 @@
 #include <set>
 #include <string>
 
-#include <zypp/APIConfig.h>
+#include <zypp-core/Globals.h>
 #include <zypp/base/NonCopyable.h>
 #include <zypp/base/PtrTypes.h>
 
@@ -29,6 +29,11 @@
 #include <zypp/DownloadMode.h>
 #include <zypp/target/rpm/RpmFlags.h>
 
+namespace zyppng {
+  // just for the friend declaration
+  template<typename T> class RepoManager;
+}
+
 ///////////////////////////////////////////////////////////////////
 namespace zypp
 { /////////////////////////////////////////////////////////////////
@@ -60,7 +65,7 @@ namespace zypp
    * \ingroup ZyppConfig
    * \ingroup Singleton
   */
-  class ZConfig : private base::NonCopyable
+  class ZYPP_API ZConfig : private base::NonCopyable
   {
     public:
 
@@ -87,6 +92,13 @@ namespace zypp
        */
       void setRepoManagerRoot ( const Pathname &root );
 
+      /** Announce a target root directory without launching the Target.
+       * This can be used by workflows which want to run ---root but
+       * without immediately launching the \ref Target. The value is
+       * cleared as soon as a real \ref Target is up.
+       */
+      void announceSystemRoot( const Pathname & root_r );
+
     public:
 
       /** The autodetected system architecture. */
@@ -488,22 +500,37 @@ namespace zypp
        */
       bool apply_locks_file() const;
 
+#if LEGACY(1735)
       /**
        * Path where the update items are kept (/var/adm)
        */
       Pathname update_dataPath() const;
 
-     /**
-      * Path where the repo metadata is downloaded and kept (update_dataPath()/).
-      * \ingroup g_ZC_REPOCACHE
-      */
+      /**
+       * Path where the update scripts are stored ( /var/adm/update-scripts )
+       */
       Pathname update_scriptsPath() const;
 
-     /**
-      * Path where the repo solv files are created and kept (update_dataPath()/solv).
-      * \ingroup g_ZC_REPOCACHE
-      */
+      /**
+       * Path where the update messages are stored ( /var/adm/update-messages )
+       */
       Pathname update_messagesPath() const;
+#else
+      /**
+       * Path where the update items are kept (/var/adm)
+       */
+      static Pathname update_dataPath();
+
+      /**
+       * Path where the update scripts are stored ( /var/adm/update-scripts )
+       */
+      static Pathname update_scriptsPath();
+
+      /**
+       * Path where the update messages are stored ( /var/adm/update-messages )
+       */
+      static Pathname update_messagesPath();
+#endif
 
       /** \name Command to be invoked to send update messages. */
       //@{
@@ -570,12 +597,19 @@ namespace zypp
 
     public:
       class Impl;
+
+      ZConfig(const ZConfig &) = delete;
+      ZConfig(ZConfig &&) = delete;
+      ZConfig &operator=(const ZConfig &) = delete;
+      ZConfig &operator=(ZConfig &&) = delete;
+
       /** Dtor */
       ~ZConfig();
       void notifyTargetChanged();  ///< internal
 
   private:
       friend class RepoManager;
+      template<typename T> friend class zyppng::RepoManager;
       /** The builtin config file value. */
       Pathname builtinRepoCachePath() const;
       /** The builtin config file value. */
