@@ -356,7 +356,7 @@ multifetchworker::writefunction(char *ptr, std::optional<off_t> offset, size_t b
   }
 
   const auto &blk = _blocks[*currRange];
-  off_t seekTo = blk.start + blk.bytesWritten;
+  off_t seekTo = blk._start + blk.bytesWritten;
 
   if ( ftell( _request->_fp ) != seekTo ) {
     // if we can't seek the file there is no purpose in trying again
@@ -378,7 +378,7 @@ bool multifetchworker::beginRange ( off_t workerRangeOff, std::string &cancelRea
   if ( currRangeState == Stripe::FINALIZED ){
     cancelReason = "Cancelled because stripe block is already finalized";
     _state = WORKER_DISCARD;
-    WAR << "#" << _workerno << ": trying to start a range ("<<stripeRangeOff<<"["<< _blocks[workerRangeOff].start <<" : "<<_blocks[workerRangeOff].len<<"]) that was already finalized, cancelling. Stealing was: " << _request->_stealing << endl;
+    WAR << "#" << _workerno << ": trying to start a range ("<<stripeRangeOff<<"["<< _blocks[workerRangeOff]._start <<" : "<<_blocks[workerRangeOff]._len<<"]) that was already finalized, cancelling. Stealing was: " << _request->_stealing << endl;
     return false;
   }
   stripeDesc.blockStates[stripeRangeOff] = currRangeState == Stripe::PENDING ?  Stripe::FETCH : Stripe::COMPETING;
@@ -400,12 +400,12 @@ bool multifetchworker::finishedRange ( off_t workerRangeOff, bool validated, std
   if ( currRangeState == Stripe::FETCH ) {
     // only us who wrote here, block is finalized
     stripeDesc.blockStates[stripeRangeOff] = Stripe::FINALIZED;
-    _request->_fetchedgoodsize += _blocks[workerRangeOff].len;
+    _request->_fetchedgoodsize += _blocks[workerRangeOff]._len;
   } else {
     // others wrote here, we need to check the full checksum
     if ( recheckChecksum ( workerRangeOff ) ) {
       stripeDesc.blockStates[stripeRangeOff] = Stripe::FINALIZED;
-      _request->_fetchedgoodsize += _blocks[workerRangeOff].len;
+      _request->_fetchedgoodsize += _blocks[workerRangeOff]._len;
     } else {
       // someone messed that block up, set it to refetch but continue since our
       // data is valid
@@ -690,13 +690,13 @@ bool multifetchworker::recheckChecksum( off_t workerRangeIdx )
   if ( currOf == -1 )
     return false;
 
-  if (fseeko(_request->_fp, blk.start, SEEK_SET))
+  if (fseeko(_request->_fp, blk._start, SEEK_SET))
     return false;
 
   zypp::Digest newDig = blk._digest->clone();
 
   char buf[4096];
-  size_t l = blk.len;
+  size_t l = blk._len;
   while (l) {
     size_t cnt = l > sizeof(buf) ? sizeof(buf) : l;
     if (fread(buf, cnt, 1, _request->_fp) != 1)
@@ -895,7 +895,7 @@ void multifetchworker::runjob()
     } else {
       _blocks.push_back( rangeFromBlock(stripeDesc.blocks[i]) );
       _rangeToStripeBlock.push_back( i );
-      _datasize += _blocks.back().len;
+      _datasize += _blocks.back()._len;
     }
   }
 
@@ -1082,6 +1082,8 @@ multifetchrequest::run(std::vector<Url> &urllist)
 
       // if we added a new job we have to call multi_perform once
       // to make it show up in the fd set. do not sleep in this case.
+      // setting timeout to 0 and not -1 will make sure the poll() case further down is actually entered, do not change
+      // without adapting the logic around poll
       int timeoutMs = _havenewjob ? 0 : 200;
       if ( _sleepworkers && !_havenewjob ) {
         if (_minsleepuntil == 0) {
@@ -1108,31 +1110,37 @@ multifetchrequest::run(std::vector<Url> &urllist)
       dnsFdCount = waitFds.size(); // remember how many dns fd's we have
       waitFds.insert( waitFds.end(), _curlHelper.socks.begin(), _curlHelper.socks.end() ); // add the curl fd's to the poll data
 
-      int r = zypp_detail::zypp_poll( waitFds, timeoutMs );
-      if ( r == -1 )
-        ZYPP_THROW(MediaCurlException(_baseurl, "zypp_poll() failed", "unknown error"));
-      if ( r != 0 && _lookupworkers ) {
-        for (auto workeriter = _workers.begin(); workeriter != _workers.end(); ++workeriter)
-          {
-            multifetchworker *worker = workeriter->get();
-            if (worker->_state != WORKER_LOOKUP)
-              continue;
-            (*workeriter)->dnsevent( waitFds );
-            if (worker->_state != WORKER_LOOKUP)
-              _lookupworkers--;
-          }
-      }
-      _havenewjob = false;
+      // run poll only if we either have a valid timeout or sockets to wait for... otherwise we end up waiting forever (bsc#1230912)
+      if ( !waitFds.empty() || timeoutMs != -1) {
+        int r = zypp_detail::zypp_poll( waitFds, timeoutMs );
+        if ( r == -1 )
+          ZYPP_THROW(MediaCurlException(_baseurl, "zypp_poll() failed", "unknown error"));
+        if ( r != 0 && _lookupworkers ) {
+          for (auto workeriter = _workers.begin(); workeriter != _workers.end(); ++workeriter)
+            {
+              multifetchworker *worker = workeriter->get();
+              if (worker->_state != WORKER_LOOKUP)
+                continue;
+              (*workeriter)->dnsevent( waitFds );
+              if (worker->_state != WORKER_LOOKUP)
+                _lookupworkers--;
+            }
+        }
 
-      // run curl
-      if ( r == 0 ) {
-        CURLMcode mcode = _curlHelper.handleTimout();
-        if (mcode != CURLM_OK)
-          ZYPP_THROW(MediaCurlException(_baseurl, "curl_multi_socket_action", "unknown error"));
-      } else {
-        CURLMcode mcode = _curlHelper.handleSocketActions( waitFds, dnsFdCount );
-        if (mcode != CURLM_OK)
-          ZYPP_THROW(MediaCurlException(_baseurl, "curl_multi_socket_action", "unknown error"));
+        // run curl
+        if ( r == 0 ) {
+          CURLMcode mcode = _curlHelper.handleTimout();
+          if (mcode != CURLM_OK)
+            ZYPP_THROW(MediaCurlException(_baseurl, "curl_multi_socket_action", "unknown error"));
+        } else {
+          CURLMcode mcode = _curlHelper.handleSocketActions( waitFds, dnsFdCount );
+          if (mcode != CURLM_OK)
+            ZYPP_THROW(MediaCurlException(_baseurl, "curl_multi_socket_action", "unknown error"));
+        }
+
+        // reset havenewjobs, we just called into curl_multi_socket_action ... no need to call another time just because
+        // we maybe added jobs during checking the dns worker events
+        _havenewjob = false;
       }
 
       double now = currentTime();
