@@ -13,6 +13,7 @@
 #include <zypp/base/LogTools.h>
 #include <zypp/base/String.h>
 #include <zypp/base/StringV.h>
+#include <utility>
 #include <zypp-core/base/InputStream>
 #include <zypp-core/base/UserRequestException>
 
@@ -42,7 +43,7 @@ namespace zypp
 
         using IniDict::consume;	// don't hide overloads we don't redefine here
 
-        virtual void consume( const std::string & section_r, const std::string & key_r, const std::string & value_r )
+        void consume( const std::string & section_r, const std::string & key_r, const std::string & value_r ) override
         {
           if ( key_r == "baseurl" )
           {
@@ -71,7 +72,7 @@ namespace zypp
           }
         }
 
-        virtual void garbageLine( const std::string & section_r, const std::string & line_r )
+        void garbageLine( const std::string & section_r, const std::string & line_r ) override
         {
           switch ( _inMultiline )
           {
@@ -233,17 +234,17 @@ namespace zypp
     ///////////////////////////////////////////////////////////////////
 
     RepoFileReader::RepoFileReader( const Pathname & repo_file,
-                                    const ProcessRepo & callback,
+                                    ProcessRepo  callback,
                                     const ProgressData::ReceiverFnc &progress )
-      : _callback(callback)
+      : _callback(std::move(callback))
     {
       repositories_in_stream(InputStream(repo_file), _callback, progress);
     }
 
     RepoFileReader::RepoFileReader( const InputStream &is,
-                                    const ProcessRepo & callback,
+                                    ProcessRepo  callback,
                                     const ProgressData::ReceiverFnc &progress )
-      : _callback(callback)
+      : _callback(std::move(callback))
     {
       repositories_in_stream(is, _callback, progress);
     }
