@@ -13,7 +13,7 @@
 #include <zypp/base/Function.h>
 
 #include "MediaInfoDownloader.h"
-#include <zypp/base/UserRequestException.h>
+#include <zypp-core/base/UserRequestException>
 
 
 namespace zypp
@@ -35,7 +35,7 @@ void downloadMediaInfo( const Pathname &dest_dir,
   fetcher.reset();
 }
 
-}// ns repo 
+}// ns repo
 } // ns zypp
 
 
