@@ -29,9 +29,9 @@ namespace zypp
     // Obsoletes may either match against provides, or names.
     // Configuration depends on the behaviour of rpm.
 #ifdef _RPM_5
-    ZYPP_TESTS bool obsoleteUsesProvides = true;
+    bool obsoleteUsesProvides = true;
 #else
-    ZYPP_TESTS bool obsoleteUsesProvides = false;
+    bool obsoleteUsesProvides = false;
 #endif
 
     ///////////////////////////////////////////////////////////////////
@@ -96,7 +96,7 @@ namespace zypp
 
       if ( obsoleteUsesProvides )
       {
-        WhatProvides obsoleted( item_r.obsoletes() );
+        WhatProvides obsoleted( item_r.dep_obsoletes() );
         if ( obsoleted.empty() )
           return;
 
@@ -110,7 +110,7 @@ namespace zypp
       }
       else // Obsoletes match names
       {
-        Capabilities obsoletes( item_r.obsoletes() );
+        Capabilities obsoletes( item_r.dep_obsoletes() );
         if ( obsoletes.empty() )
           return;
 
