@@ -19,6 +19,7 @@
  * 02111-1307, USA.
  */
 #include <boost/static_assert.hpp>
+#include <utility>
 
 #define ZYPP_USE_RESOLVER_INTERNALS
 
@@ -73,8 +74,8 @@ std::ostream & Resolver::dumpOn( std::ostream & os ) const
 
 //---------------------------------------------------------------------------
 
-Resolver::Resolver (const ResPool & pool)
-    : _pool(pool)
+Resolver::Resolver (ResPool  pool)
+    : _pool(std::move(pool))
     , _satResolver(NULL)
     , _poolchanged(_pool.serial() )
     , _upgradeMode              ( false )
@@ -139,6 +140,12 @@ void Resolver::setFocus( ResolverFocus focus_r )	{
 }
 ResolverFocus Resolver::focus() const			{ return _satResolver->_focus; }
 
+void Resolver::setRemoveOrphaned( bool yesno_r )        { _satResolver->_removeOrphaned = yesno_r; }
+bool Resolver::removeOrphaned() const                   { return _satResolver->_removeOrphaned; }
+
+void Resolver::setRemoveUnneeded( bool yesno_r )        { _satResolver->_removeUnneeded = yesno_r; }
+bool Resolver::removeUnneeded() const                   { return _satResolver->_removeUnneeded; }
+
 #define ZOLV_FLAG_TRIBOOL( ZSETTER, ZGETTER, ZVARDEFAULT, ZVARNAME )			\
     void Resolver::ZSETTER( TriBool state_r )						\
     { _applyDefault_##ZGETTER = indeterminate(state_r);					\
@@ -205,7 +212,7 @@ void Resolver::addExtraConflict( const Capability & capability )
 void Resolver::removeExtraConflict( const Capability & capability )
 { _extra_conflicts.erase (capability); }
 
-void Resolver::removeQueueItem( SolverQueueItem_Ptr item )
+void Resolver::removeQueueItem( const SolverQueueItem_Ptr& item )
 {
     bool found = false;
     for (SolverQueueItemList::const_iterator iter = _added_queue_items.begin();
@@ -222,7 +229,7 @@ void Resolver::removeQueueItem( SolverQueueItem_Ptr item )
     }
 }
 
-void Resolver::addQueueItem( SolverQueueItem_Ptr item )
+void Resolver::addQueueItem( const SolverQueueItem_Ptr& item )
 {
     bool found = false;
     for (SolverQueueItemList::const_iterator iter = _removed_queue_items.begin();
@@ -251,7 +258,7 @@ struct UndoTransact
         :resStatus(status)
     { }
 
-    bool operator()( PoolItem item )		// only transacts() items go here
+    bool operator()( const PoolItem& item )		// only transacts() items go here
     {
         item.status().resetTransact( resStatus );// clear any solver/establish transactions
         return true;
@@ -266,7 +273,7 @@ struct DoTransact
         :resStatus(status)
     { }
 
-    bool operator()( PoolItem item )		// only transacts() items go here
+    bool operator()( const PoolItem& item )		// only transacts() items go here
     {
         item.status().setTransact( true, resStatus );
         return true;
@@ -315,8 +322,10 @@ void Resolver::solverInit()
     _satResolver->setIgnorealreadyrecommended	( ignoreAlreadyRecommended() );
 
     if (_upgradeMode) {
-      // may overwrite some settings
-      _satResolver->setDistupgrade_removeunsupported	(false);
+      // Maybe depend on ZConfig::solverUpgradeRemoveDroppedPackages.
+      // For sure right but a change in behavior for old distros.
+      // (Will disable weakremover processing in SATResolver)
+      // _satResolver->setRemoveOrphaned( ... );
     }
 
     // Resetting additional solver information
@@ -417,7 +426,7 @@ ResolverProblemList Resolver::problems() const
 
 void Resolver::applySolutions( const ProblemSolutionList & solutions )
 {
-  for ( ProblemSolution_Ptr solution : solutions )
+  for ( const ProblemSolution_Ptr& solution : solutions )
   {
     if ( ! applySolution( *solution ) )
       break;
@@ -428,7 +437,7 @@ bool Resolver::applySolution( const ProblemSolution & solution )
 {
   bool ret = true;
   DBG << "apply solution " << solution << endl;
-  for ( SolutionAction_Ptr action : solution.actions() )
+  for ( const SolutionAction_Ptr& action : solution.actions() )
   {
     if ( ! action->execute( *this ) )
     {
