@@ -28,6 +28,7 @@
 #include <list>
 #include <string>
 
+#include <zypp/Globals.h>
 #include <zypp/base/ReferenceCounted.h>
 #include <zypp/base/NonCopyable.h>
 #include <zypp/base/PtrTypes.h>
@@ -79,7 +80,7 @@ class SolverQueueItem : public base::ReferenceCounted, private base::NonCopyable
 
   protected:
 
-    SolverQueueItem (SolverQueueItemType type, const ResPool & pool);
+    SolverQueueItem (SolverQueueItemType type, ResPool  pool);
 
   public:
 
