@@ -58,11 +58,11 @@ struct FileInfo
  *
  * <B>NEVER create <code>RpmHeader</code> from a NULL <code>Header</code>! </B>
  **/
-class RpmHeader : public BinHeader
+class ZYPP_API RpmHeader : public BinHeader
 {
 public:
-  typedef intrusive_ptr<RpmHeader> Ptr;
-  typedef intrusive_ptr<const RpmHeader> constPtr;
+  using Ptr = intrusive_ptr<RpmHeader>;
+  using constPtr = intrusive_ptr<const RpmHeader>;
 
 private:
 
@@ -81,7 +81,7 @@ public:
    **/
   RpmHeader( BinHeader::Ptr & rhs );
 
-  virtual ~RpmHeader();
+  ~RpmHeader() override;
 
   bool isSrc() const;	///< Either 'src' or 'nosrc'
   bool isNosrc() const;	///< Only 'nosrc'
@@ -183,7 +183,7 @@ public:
 
 public:
 
-  virtual std::ostream & dumpOn( std::ostream & str ) const;
+  std::ostream & dumpOn( std::ostream & str ) const override;
 
 public:
 
